==> react-native-rook-logger-react-native-0.1.1.tgz: package/src/controllers/LoggerController.ts <==
import { assign, createMachine } from 'xstate';
import { format } from 'date-fns';
import type {
  DeviceInfo,
  LoggerContext,
  LoggerEvent,
  TransmissionLog,
} from '../types/LoggerTypes';
import { Platform } from 'react-native';
import type { PlatformAndroidStatic } from 'react-native';
import type { PlatformIOSStatic } from 'react-native';
import { loggerClient } from '../config/axios';

/**
 * The function fetchDeviceInfo retrieves information about the device, including the brand, model, and
 * operating system version.
 * @returns The function `fetchDeviceInfo` returns a Promise that resolves to an object of type
 * `DeviceInfo`.
 */
const fetchDeviceInfo = (): DeviceInfo => {
  const iOS = Platform.OS === 'ios';

  if (iOS) {
    const { constants, isPad } = Platform as PlatformIOSStatic;

    return {
      brand: 'Apple',
      model: isPad ? 'iPad' : 'iPhone',
      os_version: constants.osVersion,
    };
  }

  const { constants } = Platform as PlatformAndroidStatic;

  return {
    brand: constants.Brand,
    model: constants.Model,
    os_version: constants.Fingerprint,
  };
};

/**
 * The function `sendLog` sends log data to a server using a POST request.
 * @param {LoggerContext} context - The `context` parameter is an object that contains various
 * information related to logging. Here's a breakdown of the properties:
 * @returns The function `sendLog` returns a `Promise<void>`.
 */
const sendLog = async (context: LoggerContext): Promise<void> => {
  const { content } = context;

  if (!content) return;

  const payload: any = {
    environment: context.environment,
    client_uuid: context.clientUUID,
    user_id: context.userID,
    timestamp: format(new Date(), "yyyy-MM-dd'T'HH:mm:ss'Z'"),
    platform: Platform.OS,
    device_info: context.deviceInfo,
    sdk: context.sdkInfo,
  };

  if ((content as TransmissionLog).server_response)
    payload.transmission_log = content;
  else payload.extraction_log = content;

  await loggerClient.post('/', payload);
};

export const LoggerController = createMachine<LoggerContext, LoggerEvent>(
  {
    id: 'LoggerController',
    initial: 'waiting',
    predictableActionArguments: true,
    context: {
      clientUUID: '',
      content: null,
      deviceInfo: null,
      environment: 'development',
      sdkInfo: null,
      timestamp: format(new Date(), "yyyy-MM-dd'T'HH:mm:ss'Z'"),
      userID: '',
    },
    states: {
      waiting: {
        on: {
          init: {
            target: 'idle',
            actions: ['handleInit'],
          },
        },
      },
      idle: {
        on: {
          send: {
            target: 'sending',
            actions: assign({ content: (_, event) => event.payload }),
          },
        },
      },
      sending: {
        invoke: {
          id: 'sendLog',
          src: sendLog,
          onDone: {
            target: 'idle',
          },
          onError: {
            target: 'idle',
            actions: assign((context, event) => {
              console.log(JSON.stringify(event.data));
              return {
                ...context,
              };
            }),
          },
        },
      },
    },
  },
  {
    actions: {
      handleInit: assign((context, event) => {
        if (event.type !== 'init') return { ...context };

        const deviceInfo = fetchDeviceInfo();

        return {
          ...context,
          environment: event.payload.environment,
          clientUUID: event.payload.clientUUID,
          userID: event.payload.userID || '',
          sdkInfo: event.payload.sdkInfo,
          deviceInfo,
        };
      }),
    },
  }
);

==> react-native-rook-logger-react-native-0.2.4.tgz: package/src/controllers/LoggerController.ts <==
import { assign, createMachine } from 'xstate';
import type {
  DeviceInfo,
  LoggerContext,
  LoggerEvent,
  TransmissionLog,
} from '../types/LoggerTypes';
import { Platform } from 'react-native';
import type { PlatformAndroidStatic } from 'react-native';
import type { PlatformIOSStatic } from 'react-native';
import { loggerClient } from '../config/axios';

const OS = {
  ios: 'iOS',
  android: 'Android',
  windows: 'Windows',
  macos: 'Mac OS',
  web: 'Web',
  other: 'Other',
};

/**
 * The function fetchDeviceInfo retrieves information about the device, including the brand, model, and
 * operating system version.
 * @returns The function `fetchDeviceInfo` returns a Promise that resolves to an object of type
 * `DeviceInfo`.
 */
const fetchDeviceInfo = (): DeviceInfo => {
  const iOS = Platform.OS === 'ios';

  if (iOS) {
    const { constants, isPad } = Platform as PlatformIOSStatic;

    return {
      brand: 'Apple',
      model: isPad ? 'iPad' : 'iPhone',
      os_version: constants.osVersion,
    };
  }

  const { constants } = Platform as PlatformAndroidStatic;

  return {
    brand: constants.Brand,
    model: constants.Model,
    os_version: constants.Fingerprint,
  };
};

/**
 * The function `sendLog` sends log data to a server using a POST request.
 * @param {LoggerContext} context - The `context` parameter is an object that contains various
 * information related to logging. Here's a breakdown of the properties:
 * @returns The function `sendLog` returns a `Promise<void>`.
 */
const sendLog = async (context: LoggerContext): Promise<void> => {
  const { content } = context;

  if (!content) return;

  const payload: any = {
    environment: context.environment,
    client_uuid: context.clientUUID,
    user_id: context.userID,
    timestamp: new Date().toISOString(),
    platform: OS[Platform.OS] || OS.other,
    device_info: context.deviceInfo,
    sdk: context.sdkInfo,
  };

  if ((content as TransmissionLog).server_response)
    payload.transmission_log = content;
  else payload.extraction_log = content;

  await loggerClient.post('/', payload);
};

export const LoggerController = createMachine<LoggerContext, LoggerEvent>(
  {
    id: 'LoggerController',
    initial: 'waiting',
    predictableActionArguments: true,
    context: {
      clientUUID: '',
      content: null,
      deviceInfo: null,
      environment: 'development',
      sdkInfo: null,
      timestamp: new Date().toISOString(),
      userID: '',
    },
    states: {
      waiting: {
        on: {
          init: {
            target: 'idle',
            actions: ['handleInit'],
          },
        },
      },
      idle: {
        on: {
          send: {
            target: 'sending',
            actions: assign({ content: (_, event) => event.payload }),
          },
        },
      },
      sending: {
        invoke: {
          id: 'sendLog',
          src: sendLog,
          onDone: {
            target: 'idle',
          },
          onError: {
            target: 'idle',
            actions: assign((context, _) => {
              return {
                ...context,
              };
            }),
          },
        },
      },
    },
  },
  {
    actions: {
      handleInit: assign((context, event) => {
        if (event.type !== 'init') return { ...context };

        const deviceInfo = fetchDeviceInfo();

        return {
          ...context,
          environment: event.payload.environment,
          clientUUID: event.payload.clientUUID,
          userID: event.payload.userID || '',
          sdkInfo: event.payload.sdkInfo,
          deviceInfo,
        };
      }),
    },
  }
);
